@@ -1,5 +1,5 @@
 /* GIO - GLib Input, Output and Streaming Library
- * 
+ *
  * Copyright (C) 2006-2007 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
@@ -27,7 +27,7 @@
 #ifndef __G_IO_MODULE_H__
 #define __G_IO_MODULE_H__
 
-#include <glib-object.h>
+#include <gio/giotypes.h>
 #include <gmodule.h>
 
 G_BEGIN_DECLS
@@ -41,22 +41,19 @@ G_BEGIN_DECLS
 
 /**
  * GIOModule:
- * 
+ *
  * Opaque module base class for extending GIO.
  **/
-typedef struct _GIOModule GIOModule;
 typedef struct _GIOModuleClass GIOModuleClass;
 
-typedef struct _GIOExtensionPoint GIOExtensionPoint;
-typedef struct _GIOExtension GIOExtension;
+GType              g_io_module_get_type                       (void) G_GNUC_CONST;
+GIOModule         *g_io_module_new                            (const gchar       *filename);
 
-GType      g_io_module_get_type (void) G_GNUC_CONST;
-GIOModule *g_io_module_new      (const gchar *filename);
+void               g_io_modules_scan_all_in_directory         (const char        *dirname);
+GList             *g_io_modules_load_all_in_directory         (const gchar       *dirname);
 
-GList *g_io_modules_load_all_in_directory            (const char *dirname);
-
-GIOExtensionPoint *g_io_extension_point_register              (const char        *extension_point);
-GIOExtensionPoint *g_io_extension_point_lookup                (const char        *extension_point);
+GIOExtensionPoint *g_io_extension_point_register              (const char        *name);
+GIOExtensionPoint *g_io_extension_point_lookup                (const char        *name);
 void               g_io_extension_point_set_required_type     (GIOExtensionPoint *extension_point,
 							       GType              type);
 GType              g_io_extension_point_get_required_type     (GIOExtensionPoint *extension_point);
@@ -68,29 +65,63 @@ GIOExtension *     g_io_extension_point_implement             (const char
 							       const char        *extension_name,
 							       gint               priority);
 
-GType                   g_io_extension_get_type     (GIOExtension *extension);
-const char *            g_io_extension_get_name     (GIOExtension *extension);
-gint                    g_io_extension_get_priority (GIOExtension *extension);
-GTypeClass*             g_io_extension_ref_class    (GIOExtension *extension);
+GType              g_io_extension_get_type                    (GIOExtension      *extension);
+const char *       g_io_extension_get_name                    (GIOExtension      *extension);
+gint               g_io_extension_get_priority                (GIOExtension      *extension);
+GTypeClass*        g_io_extension_ref_class                   (GIOExtension      *extension);
+
 
 /* API for the modules to implement */
+
 /**
  * g_io_module_load:
  * @module: a #GIOModule.
- * 
- * Required API for GIO modules to implement. This function is ran after the module
- * has been loaded into GIO, to initialize the module.
+ *
+ * Required API for GIO modules to implement.
+ * This function is ran after the module has been loaded into GIO,
+ * to initialize the module.
  **/
-void        g_io_module_load     (GIOModule   *module);
+void   g_io_module_load   (GIOModule *module);
 
 /**
  * g_io_module_unload:
  * @module: a #GIOModule.
- * 
- * Required API for GIO modules to implement. This function is ran when the module
- * is being unloaded from GIO, to finalize the module.
+ *
+ * Required API for GIO modules to implement.
+ * This function is ran when the module is being unloaded from GIO,
+ * to finalize the module.
  **/
-void        g_io_module_unload   (GIOModule   *module);
+void   g_io_module_unload (GIOModule *module);
+
+/**
+ * g_io_module_query:
+ *
+ * Optional API for GIO modules to implement.
+ *
+ * Should return a list of all the extension points that may be
+ * implemented in this module.
+ *
+ * This method will not be called in normal use, however it may be
+ * called when probing existing modules and recording which extension
+ * points that this modle is used for. This means we won't have to
+ * load and initialze this module unless its needed
+ *
+ * If this function is not implemented by the module the module will
+ * always be loaded, initialized and then unloaded on application startup
+ * so that it can register its extension points during init.
+ *
+ * Note that a module need not actually implement all the extension points
+ * that g_io_module_query returns, since the exact list of extension may
+ * depend on runtime issues. However all extension points actually implemented
+ * must be returned by g_io_module_query (if defined).
+ *
+ * When installing a module that implements g_io_module_query you must
+ * run gio-querymodules in order to build the cache files required for
+ * lazy loading.
+ *
+ * Since: 2.24
+ **/
+char **g_io_module_query (void);
 
 G_END_DECLS
 
